@@ -296,6 +296,7 @@ class MBAR:
         for solver in solver_protocol:
             if 'options' not in solver:
                 solver['options'] = dict()
+                solver['options']['maximum_iterations'] = maximum_iterations
             if 'verbose' not in solver['options']:
                 # should add in other ways to get information out of the scipy solvers, not just adaptive,
                 # which might involve passing in different combinations of options, and passing out other strings.
@@ -1473,7 +1474,7 @@ class MBAR:
             indices = np.where(bin_n == i)
 
             # Sanity check.
-            if (len(indices) == 0):
+            if (len(indices[0]) == 0):
                 raise DataError("WARNING: bin %d has no samples -- all bins must have at least one sample." % i)
 
             # Compute dimensionless free energy of occupying state i.
